#
# spec file for package python-elasticsearch-dsl
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-elasticsearch-dsl
Version:        8.12.0
Release:        1.2
Summary:        Python client for Elasticsearch
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/elasticsearch/elasticsearch-dsl-py
Source:         https://github.com/elastic/elasticsearch-dsl-py/archive/refs/tags/v%{version}.tar.gz#/elasticsearch-dsl-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# gh#elastic/elasticsearch-dsl-py#1569
Requires:       python-elasticsearch >= 8.0.0
Requires:       python-python-dateutil
Suggests:       python-pytz
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module elasticsearch >= 8.0.0}
BuildRequires:  %{python_module pytest >= 3.0.0}
BuildRequires:  %{python_module python-dateutil}
BuildRequires:  %{python_module pytz}
# /SECTION
%python_subpackages

%description
Python client for Elasticsearch.

%prep
%autosetup -p1 -n elasticsearch-dsl-py-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc AUTHORS Changelog.rst README
%license LICENSE
%{python_sitelib}/elasticsearch_dsl
%{python_sitelib}/elasticsearch_dsl-%{version}.dist-info

%changelog
* Sat Jan 20 2024 Dirk Müller <dmueller@suse.com>
- update to 8.12.0:
  * Added Search.knn() method
  * Added Search.rank() method (undocumented as it still is in
    technical preview)
  * Fixed importing collapse from dictionary
* Mon Nov 27 2023 Dirk Müller <dmueller@suse.com>
- update to 8.11.0:
  * Added support for Python 3.12
  * Added support for Search.collase()
* Fri Sep  1 2023 Matej Cepl <mcepl@suse.com>
- Update to 8.9.0:
  - Added Elasticsearch 8.x support
  - Dropped support for Python 2.7 and 3.5
  - Added support for Python 3.10 and 3.11
  - Added the MultiTerms aggregation
  - Added the CombinedFields query
- Remove upstreamed python-elasticsearch-dsl-no-mock.patch.
* Wed May 10 2023 Daniel Garcia <daniel.garcia@suse.com>
- Delete drop-python2-support.patch
- Update to 7.4.1:
  * Fixed DeprecationWarnings that would be emitted from deprecated
    usages of the body parameter in the Python Elasticsearch client.
* Mon Nov 28 2022 Daniel Garcia <daniel.garcia@suse.com>
- Add drop-python2-support.patch from upstream
  gh#elastic/elasticsearch-dsl-py@f7f85a5db8f2
- Remove python-six dependency
* Tue Oct 18 2022 Matej Cepl <mcepl@suse.com>
- Update to 7.4.0:
  - Added the ConstantKeyword, RankFeatures field types
  - Added the ScriptScore query type
  - Added UpdateByQueryResponse.success() method
  - Added return_doc_meta parameter to Document.save() and
    Document.update() for accessing the complete API response
  - Added support for calendar_interval and fixed_interval to
    DateHistogramFacet
  - Added Document.exists() method
  - Added support for the year interval to DateHistogramFacet
  - Fixed issue where to_dict() should be called recursively on
    Search.extras and **kwargs
  - Fixed inverse of an empty Bool query should be MatchNone
  - Fixed issue between retry_on_conflict and optimistic
    concurrency control within Document.update()
- Update to 7.3.0:
  - Added Intervals, MatchBoolPrefix, Shape, and Wrapper queries
  - Added Boxplot, RareTerms, VariableWidthHistogram,
    MedianAbsoluteDeviation, TTest, CumulativeCardinality,
    Inference, MovingPercentiles, and Normalize aggregations
  - Added __all__ and removed all star imports from
    elasticsearch_dsl namespace to avoid leaking unintended names
  - Fixed an issue where Object and Nested could mutate the inner
    doc_class mapping
  - Fixed a typo in query SpanContaining, previously was
    SpanContainining
- Limit required (and buildrequired) elasticsearch to < 8
  (gh#elastic/elasticsearch-dsl-py#1569).
* Mon May 23 2022 pgajdos@suse.com
- do not require python-mock for build
- added patches
  fix https://github.com/elastic/elasticsearch-dsl-py/issues/1596
  + python-elasticsearch-dsl-no-mock.patch
* Fri Nov 27 2020 John Vandenberg <jayvdb@gmail.com>
- Resume builds by removing unnecessary build dependency coverage < 5
* Thu Aug 20 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v7.2.1
* Tue Jul 16 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v7.0.0
